@@ -82,14 +82,13 @@ class DiscreteEnv(gym.Env):
 #"action" argument is one value in the range of the action space (logit transform)
   def step(self, action):
     
-    self.state = self.df
-    
+    self.state = self.df.sample(n=1, random_state=1).values.reshape(3,) 
     
     data = []
-    for f in self.state.itertuples(index=False):
-      Xs = f[0]
-      Xa = f[1]
-      Y = f[2]
+    for self.state in self.state.itertuples(index=False):
+      Xs = self.state[0]
+      Xa = self.state[1]
+      Y = self.state[2]
       Xsa=(self.thetas[0])+(self.thetas[1])*(Xs)+(self.thetas[2])*(Xa)
       rho2 = (1/(1+np.exp(-Xsa)))  #prob of Y=1
       g2 = ((Xa) + 0.5*((Xa)+math.sqrt(1+(Xa)**2)))*(1-rho2) + ((Xa) - 0.5*((Xa)+math.sqrt(1+(Xa)**2)))*rho2
@@ -142,7 +141,7 @@ class DiscreteEnv(gym.Env):
 
 #reset state and horizon    
   def reset(self):
-    self.state=self.df
+    self.state= self.df.sample(n=1, random_state=1).values.reshape(3,) 
     self.horizon = 20
     return self.state
 
